@@ -36,8 +36,7 @@
 #include <QStackedWidget>
 
 KOViewManager::KOViewManager(CalendarView *mainView)
-    : QObject()
-    , mMainView(mainView)
+    : mMainView(mainView)
 {
     connect(mainView, &CalendarView::calendarAdded, this, &KOViewManager::addCalendar);
     connect(mainView, &CalendarView::calendarRemoved, this, &KOViewManager::removeCalendar);
@@ -50,16 +49,63 @@ KOrg::BaseView *KOViewManager::currentView()
     return mCurrentView;
 }
 
+KActionCollection *KOViewManager::getActionCollection()
+{
+    KActionCollection *collection = nullptr;
+    KOrg::MainWindow *w = ActionManager::findInstance(QUrl());
+    if (w) {
+        collection = w->getActionCollection();
+    }
+    return collection;
+}
+
+QAction *KOViewManager::viewToAction(const QString &view, RangeMode rangeMode)
+{
+    QAction *action = nullptr;
+    KActionCollection *ac = getActionCollection();
+    if (!ac) {
+        return action;
+    }
+
+    if (view == QLatin1StringView("WhatsNext")) {
+        action = ac->action(QStringLiteral("view_whatsnext"));
+    } else if (view == QLatin1StringView("List")) {
+        action = ac->action(QStringLiteral("view_list"));
+    } else if (view == QLatin1StringView("Journal")) {
+        action = ac->action(QStringLiteral("view_journal"));
+    } else if (view == QLatin1StringView("Todo")) {
+        action = ac->action(QStringLiteral("view_todo"));
+    } else if (view == QLatin1StringView("Timeline")) {
+        action = ac->action(QStringLiteral("view_timeline"));
+    } else if ((view == QLatin1StringView("Month")) || (view == QLatin1StringView("OldMonth"))) {
+        action = ac->action(QStringLiteral("view_month"));
+    } else if (view == QLatin1StringView("Agenda")) {
+        switch (rangeMode) {
+        case WORK_WEEK_RANGE:
+            action = ac->action(QStringLiteral("select_workweek"));
+            break;
+        case NEXTX_RANGE:
+            action = ac->action(QStringLiteral("select_nextx"));
+            break;
+        case DAY_RANGE:
+            action = ac->action(QStringLiteral("select_day"));
+            break;
+        default:
+            action = ac->action(QStringLiteral("select_week"));
+            break;
+        }
+    }
+    Q_ASSERT_X(action, "no such view", qPrintable(view));
+    return action;
+}
+
 void KOViewManager::readSettings(KConfig *config)
 {
-    KConfigGroup generalConfig(config, QStringLiteral("General"));
+    KConfigGroup const generalConfig(config, QStringLiteral("General"));
     const QString view = generalConfig.readEntry("Current View");
 
     if (view == QLatin1StringView("WhatsNext")) {
         showWhatsNextView();
-    } else if (view == QLatin1StringView("OldMonth")) {
-        // the oldmonth view is gone, so we assume the new month view
-        showMonthView();
     } else if (view == QLatin1StringView("List")) {
         showListView();
         mListView->readSettings(config);
@@ -69,7 +115,7 @@ void KOViewManager::readSettings(KConfig *config)
         showTodoView();
     } else if (view == QLatin1StringView("Timeline")) {
         showTimeLineView();
-    } else if (view == QLatin1StringView("Month")) {
+    } else if ((view == QLatin1StringView("Month")) || (view == QLatin1StringView("OldMonth"))) {
         showMonthView();
     } else {
         showAgendaView();
@@ -158,30 +204,17 @@ void KOViewManager::showView(KOrg::BaseView *view)
     raiseCurrentView();
     mMainView->processIncidenceSelection(Akonadi::Item(), QDate());
     mMainView->updateView();
-    KOrg::MainWindow *w = ActionManager::findInstance(QUrl());
+    KActionCollection *ac = getActionCollection();
+    if (ac) {
+        if (QAction *action = ac->action(QStringLiteral("configure_view"))) {
+            action->setEnabled(view->hasConfigurationDialog());
+        }
 
-    if (w) {
-        KActionCollection *ac = w->getActionCollection();
-        if (ac) {
-            if (QAction *action = ac->action(QStringLiteral("configure_view"))) {
-                action->setEnabled(view->hasConfigurationDialog());
-            }
-
-            const QStringList zoomActions = QStringList() << QStringLiteral("zoom_in_horizontally") << QStringLiteral("zoom_out_horizontally")
-                                                          << QStringLiteral("zoom_in_vertically") << QStringLiteral("zoom_out_vertically");
-            const QStringList rangeActions = QStringList()
-                << QStringLiteral("select_workweek") << QStringLiteral("select_week") << QStringLiteral("select_day") << QStringLiteral("select_nextx");
-
-            for (int i = 0; i < zoomActions.size(); ++i) {
-                if (QAction *action = ac->action(zoomActions[i])) {
-                    action->setEnabled(view->supportsZoom());
-                }
-            }
-
-            for (int i = 0; i < rangeActions.size(); ++i) {
-                if (QAction *action = ac->action(rangeActions[i])) {
-                    action->setEnabled(view->supportsDateRangeSelection());
-                }
+        const QStringList zoomActions = QStringList() << QStringLiteral("zoom_in_horizontally") << QStringLiteral("zoom_out_horizontally")
+                                                      << QStringLiteral("zoom_in_vertically") << QStringLiteral("zoom_out_vertically");
+        for (int i = 0; i < zoomActions.size(); ++i) {
+            if (QAction *action = ac->action(zoomActions[i])) {
+                action->setEnabled(view->supportsZoom());
             }
         }
     }
@@ -189,22 +222,19 @@ void KOViewManager::showView(KOrg::BaseView *view)
 
 void KOViewManager::goMenu(bool enable)
 {
-    KOrg::MainWindow *w = ActionManager::findInstance(QUrl());
-    if (w) {
-        KActionCollection *ac = w->getActionCollection();
-        if (ac) {
-            QAction *action = ac->action(QStringLiteral("go_today"));
-            if (action) {
-                action->setEnabled(enable);
-            }
-            action = ac->action(QStringLiteral("go_previous"));
-            if (action) {
-                action->setEnabled(enable);
-            }
-            action = ac->action(QStringLiteral("go_next"));
-            if (action) {
-                action->setEnabled(enable);
-            }
+    KActionCollection *ac = getActionCollection();
+    if (ac) {
+        QAction *action = ac->action(QStringLiteral("go_today"));
+        if (action) {
+            action->setEnabled(enable);
+        }
+        action = ac->action(QStringLiteral("go_previous"));
+        if (action) {
+            action->setEnabled(enable);
+        }
+        action = ac->action(QStringLiteral("go_next"));
+        if (action) {
+            action->setEnabled(enable);
         }
     }
 }
@@ -293,8 +323,6 @@ void KOViewManager::connectView(KOrg::BaseView *view)
     connect(view, &BaseView::startMultiModify, mMainView, &CalendarView::startMultiModify);
     connect(view, &BaseView::endMultiModify, mMainView, &CalendarView::endMultiModify);
 
-    connect(mMainView, &CalendarView::newIncidenceChanger, view, &BaseView::setIncidenceChanger);
-
     connect(mMainView, &CalendarView::calendarAdded, view, &BaseView::calendarAdded);
     connect(mMainView, &CalendarView::calendarRemoved, view, &BaseView::calendarRemoved);
 
@@ -353,11 +381,49 @@ void KOViewManager::addView(KOrg::BaseView *view, bool isTab)
     if (!isTab) {
         mMainView->viewStack()->addWidget(view);
     }
-    for (const auto &calendar : mCalendars) {
+    for (const auto &calendar : std::as_const(mCalendars)) {
         view->calendarAdded(calendar);
     }
 }
 
+void KOViewManager::viewActionEnable(QObject *obj)
+{
+    viewActionEnable(qobject_cast<QAction *>(obj));
+}
+
+void KOViewManager::viewActionEnable(QAction *action)
+{
+    if (!action) {
+        return;
+    }
+
+    KActionCollection *ac = getActionCollection();
+    if (!ac) {
+        return;
+    }
+
+    /* Do nothing -- the action hasn't changed since last time */
+    if (mLastViewAction && action == mLastViewAction) {
+        return;
+    }
+
+    /* Do nothing for top-level agenda view button */
+    if (action == ac->action(QStringLiteral("view_agenda"))) {
+        return;
+    }
+
+    /* Re-enable last view action */
+    if (mLastViewAction) {
+        mLastViewAction->setEnabled(true);
+    }
+
+    /* Disable the any newly selected action */
+    action->setEnabled(false);
+
+    /* Save for the next time */
+    mLastViewAction = action;
+}
+
 void KOViewManager::showMonthView()
 {
     if (!mMonthView) {
@@ -366,6 +432,7 @@ void KOViewManager::showMonthView()
         addView(mMonthView);
         connect(mMonthView, &MonthView::fullViewChanged, mMainView, &CalendarView::changeFullView);
     }
+    viewActionEnable(viewToAction(QStringLiteral("Month"), NO_RANGE));
     goMenu(true);
     showView(mMonthView);
 }
@@ -377,6 +444,7 @@ void KOViewManager::showWhatsNextView()
         mWhatsNextView->setIdentifier("DefaultWhatsNextView");
         addView(mWhatsNextView);
     }
+    viewActionEnable(viewToAction(QStringLiteral("WhatsNext"), NO_RANGE));
     goMenu(true);
     showView(mWhatsNextView);
 }
@@ -388,6 +456,7 @@ void KOViewManager::showListView()
         mListView->setIdentifier("DefaultListView");
         addView(mListView);
     }
+    viewActionEnable(viewToAction(QStringLiteral("List"), NO_RANGE));
     goMenu(true);
     showView(mListView);
 }
@@ -405,7 +474,7 @@ void KOViewManager::showAgendaView()
             connect(mAgendaViewTabs, &QTabWidget::currentChanged, this, &KOViewManager::currentAgendaViewTabChanged);
             mMainView->viewStack()->addWidget(mAgendaViewTabs);
 
-            KConfigGroup viewConfig = KSharedConfig::openConfig()->group(QStringLiteral("Views"));
+            KConfigGroup const viewConfig = KSharedConfig::openConfig()->group(QStringLiteral("Views"));
             mAgendaViewTabIndex = viewConfig.readEntry("Agenda View Tab Index", 0);
         }
         parent = mAgendaViewTabs;
@@ -449,6 +518,7 @@ void KOViewManager::showAgendaView()
     }
 
     goMenu(true);
+
     if (showBoth) {
         showView(static_cast<KOrg::BaseView *>(mAgendaViewTabs->currentWidget()));
     } else if (showMerged) {
@@ -456,38 +526,47 @@ void KOViewManager::showAgendaView()
     } else if (showSideBySide) {
         showView(mAgendaSideBySideView);
     }
+    viewActionEnable(viewToAction(QStringLiteral("Agenda"), mRangeMode));
 }
 
 void KOViewManager::selectDay()
 {
+    showAgendaView();
     mRangeMode = DAY_RANGE;
+    viewActionEnable(viewToAction(QStringLiteral("Agenda"), mRangeMode));
     const QDate date = mMainView->activeDate(true);
     mMainView->dateNavigator()->selectDate(date);
 }
 
 void KOViewManager::selectWorkWeek()
 {
+    showAgendaView();
     if (KOGlobals::self()->getWorkWeekMask() != 0) {
         mRangeMode = WORK_WEEK_RANGE;
-        QDate date = mMainView->activeDate();
+        QDate const date = mMainView->activeDate();
         mMainView->dateNavigator()->selectWorkWeek(date);
     } else {
         KMessageBox::error(mMainView,
                            i18n("Unable to display the work week since there are no work days configured. "
                                 "Please properly configure at least 1 work day in the Time and Date preferences."));
     }
+    viewActionEnable(viewToAction(QStringLiteral("Agenda"), mRangeMode));
 }
 
 void KOViewManager::selectWeek()
 {
+    showAgendaView();
     mRangeMode = WEEK_RANGE;
-    QDate date = mMainView->activeDate();
+    viewActionEnable(viewToAction(QStringLiteral("Agenda"), mRangeMode));
+    QDate const date = mMainView->activeDate();
     mMainView->dateNavigator()->selectWeek(date);
 }
 
 void KOViewManager::selectNextX()
 {
+    showAgendaView();
     mRangeMode = NEXTX_RANGE;
+    viewActionEnable(viewToAction(QStringLiteral("Agenda"), mRangeMode));
     mMainView->dateNavigator()->selectDates(QDate::currentDate(), KOPrefs::instance()->mNextXDays);
 }
 
@@ -499,9 +578,10 @@ void KOViewManager::showTodoView()
         addView(mTodoView);
         connectTodoView(mTodoView);
 
-        KSharedConfig::Ptr config = KSharedConfig::openConfig();
+        KSharedConfig::Ptr const config = KSharedConfig::openConfig();
         mTodoView->restoreLayout(config.data(), QStringLiteral("Todo View"), false);
     }
+    viewActionEnable(viewToAction(QStringLiteral("Todo"), NO_RANGE));
     goMenu(false);
     showView(mTodoView);
 }
@@ -513,6 +593,7 @@ void KOViewManager::showJournalView()
         mJournalView->setIdentifier("DefaultJournalView");
         addView(mJournalView);
     }
+    viewActionEnable(viewToAction(QStringLiteral("Journal"), NO_RANGE));
     goMenu(true);
     showView(mJournalView);
 }
@@ -524,6 +605,7 @@ void KOViewManager::showTimeLineView()
         mTimelineView->setIdentifier("DefaultTimelineView");
         addView(mTimelineView);
     }
+    viewActionEnable(viewToAction(QStringLiteral("Timeline"), NO_RANGE));
     goMenu(true);
     showView(mTimelineView);
 }
@@ -581,11 +663,12 @@ QWidget *KOViewManager::widgetForView(KOrg::BaseView *view) const
 
 void KOViewManager::currentAgendaViewTabChanged(int index)
 {
-    KSharedConfig::Ptr config = KSharedConfig::openConfig();
+    KSharedConfig::Ptr const config = KSharedConfig::openConfig();
     KConfigGroup viewConfig(config, QStringLiteral("Views"));
     viewConfig.writeEntry("Agenda View Tab Index", mAgendaViewTabs->currentIndex());
 
     if (index > -1) {
+        viewActionEnable(sender());
         goMenu(true);
         QWidget *widget = mAgendaViewTabs->widget(index);
         if (widget) {
