@@ -5,9 +5,10 @@
  */
 
 #include "reparentingmodel.h"
-
 #include "korganizer_debug.h"
 
+#include <algorithm>
+
 /*
  * Notes:
  * * layoutChanged must never add or remove nodes.
@@ -21,9 +22,9 @@ ReparentingModel::Node::Node(ReparentingModel &model)
 {
 }
 
-ReparentingModel::Node::Node(ReparentingModel &model, ReparentingModel::Node *p, const QModelIndex &srcIndex)
-    : sourceIndex(srcIndex)
-    , parent(p)
+ReparentingModel::Node::Node(ReparentingModel &model, ReparentingModel::Node *parent, const QModelIndex &sourceIndex)
+    : sourceIndex(sourceIndex)
+    , parent(parent)
     , personModel(model)
     , mIsSourceNode(true)
 {
@@ -66,12 +67,6 @@ ReparentingModel::Node::Ptr ReparentingModel::Node::searchNode(ReparentingModel:
     return nodePtr;
 }
 
-void ReparentingModel::Node::reparent(ReparentingModel::Node *node)
-{
-    Node::Ptr nodePtr = searchNode(node);
-    addChild(nodePtr);
-}
-
 void ReparentingModel::Node::addChild(const ReparentingModel::Node::Ptr &node)
 {
     node->parent = this;
@@ -215,11 +210,10 @@ void ReparentingModel::addNode(const ReparentingModel::Node::Ptr &node)
     // otherwise we run into the problem that while a node is being removed,
     // the async request could be triggered (due to a changed signal),
     // resulting in the node getting read immediately after it had been removed.
-    for (const ReparentingModel::Node::Ptr &existing : std::as_const(mProxyNodes)) {
-        if (*existing == *node) {
-            // qCDebug(KORGANIZER_LOG) << "node is already existing";
-            return;
-        }
+    if (std::ranges::any_of(mProxyNodes, [node](const auto &existing) {
+            return *existing == *node;
+        })) {
+        return;
     }
     mNodesToAdd << node;
     qRegisterMetaType<Node::Ptr>("Node::Ptr");
@@ -228,12 +222,12 @@ void ReparentingModel::addNode(const ReparentingModel::Node::Ptr &node)
 
 void ReparentingModel::doAddNode(const Node::Ptr &node)
 {
-    for (const ReparentingModel::Node::Ptr &existing : std::as_const(mProxyNodes)) {
-        if (*existing == *node) {
-            // qCDebug(KORGANIZER_LOG) << "node is already existing";
-            return;
-        }
+    if (std::ranges::any_of(mProxyNodes, [node](const auto &existing) {
+            return *existing == *node;
+        })) {
+        return;
     }
+
     // If a datachanged call triggered this through checkSourceIndex, right after a person node has been removed.
     // We'd end-up re-inserting the node that has just been removed. Therefore removeNode can cancel the pending addNode
     // call through mNodesToAdd.
@@ -263,13 +257,14 @@ void ReparentingModel::doAddNode(const Node::Ptr &node)
 
 void ReparentingModel::updateNode(const ReparentingModel::Node::Ptr &node)
 {
-    for (const ReparentingModel::Node::Ptr &existing : std::as_const(mProxyNodes)) {
-        if (*existing == *node) {
-            existing->update(node);
-            const QModelIndex i = index(existing.data());
-            Q_EMIT dataChanged(i, i);
-            return;
-        }
+    const auto it = std::ranges::find_if(mProxyNodes, [node](const Node::Ptr &existing) {
+        return *existing == *node;
+    });
+    if (it != mProxyNodes.end()) {
+        (*it)->update(node);
+        const QModelIndex i = index((*it).data());
+        Q_EMIT dataChanged(i, i);
+        return;
     }
 
     qCWarning(KORGANIZER_LOG) << objectName() << "no node to update, create new node";
@@ -298,19 +293,6 @@ void ReparentingModel::removeNode(const ReparentingModel::Node &node)
     }
 }
 
-void ReparentingModel::setNodes(const QList<Node::Ptr> &nodes)
-{
-    for (const ReparentingModel::Node::Ptr &node : nodes) {
-        addNode(node);
-    }
-    const auto currentProxyNodes = mProxyNodes;
-    for (const ReparentingModel::Node::Ptr &node : currentProxyNodes) {
-        if (!nodes.contains(node)) {
-            removeNode(*node);
-        }
-    }
-}
-
 void ReparentingModel::clear()
 {
     beginResetModel();
@@ -357,13 +339,14 @@ void ReparentingModel::onSourceRowsAboutToBeInserted(const QModelIndex &parent,
 
 ReparentingModel::Node *ReparentingModel::getReparentNode(const QModelIndex &sourceIndex)
 {
-    for (const Node::Ptr &proxyNode : std::as_const(mProxyNodes)) {
-        // Reparent source nodes according to the provided rules
-        // The proxy can be ignored if it is a duplicate, so only reparent to proxies that are in the model
-        if (proxyNode->parent && proxyNode->adopts(sourceIndex)) {
-            Q_ASSERT(validateNode(proxyNode.data()));
-            return proxyNode.data();
-        }
+    const auto it = std::ranges::find_if(mProxyNodes, [sourceIndex](const Node::Ptr &proxyNode) {
+        // Re-parent source nodes according to the provided rules
+        // The proxy can be ignored if it is a duplicate, so only re-parent to proxies that are in the model
+        return (proxyNode->parent && proxyNode->adopts(sourceIndex));
+    });
+    if (it != mProxyNodes.end()) {
+        Q_ASSERT(validateNode((*it).data()));
+        return (*it).data();
     }
     return nullptr;
 }
@@ -380,14 +363,14 @@ ReparentingModel::Node *ReparentingModel::getParentNode(const QModelIndex &sourc
     return nullptr;
 }
 
-void ReparentingModel::appendSourceNode(Node *parentNode, const QModelIndex &sourceIndex, const QModelIndexList &skip)
+void ReparentingModel::appendSourceNode(Node *parentNode, const QModelIndex &sourceParent, const QModelIndexList &skip)
 {
-    mNodeManager->checkSourceIndex(sourceIndex);
+    mNodeManager->checkSourceIndex(sourceParent);
 
-    Node::Ptr node(new Node(*this, parentNode, sourceIndex));
+    const Node::Ptr node(new Node(*this, parentNode, sourceParent));
     parentNode->children.append(node);
     Q_ASSERT(validateNode(node.data()));
-    rebuildFromSource(node.data(), sourceIndex, skip);
+    rebuildFromSource(node.data(), sourceParent, skip);
 }
 
 QModelIndexList ReparentingModel::descendants(const QModelIndex &sourceIndex)
@@ -400,9 +383,9 @@ QModelIndexList ReparentingModel::descendants(const QModelIndex &sourceIndex)
         const int count = sourceModel()->rowCount(sourceIndex);
         list.reserve(count * 2);
         for (int i = 0; i < count; ++i) {
-            const QModelIndex index = sourceModel()->index(i, 0, sourceIndex);
-            list << index;
-            list << descendants(index);
+            const QModelIndex idx = sourceModel()->index(i, 0, sourceIndex);
+            list << idx;
+            list << descendants(idx);
         }
     }
     return list;
@@ -433,8 +416,8 @@ void ReparentingModel::removeDuplicates(const QModelIndex &sourceIndex)
 void ReparentingModel::onSourceRowsInserted(const QModelIndex &parent, int start, int end)
 {
     // qCDebug(KORGANIZER_LOG) << objectName() << parent << start << end;
-    for (int row = start; row <= end; row++) {
-        QModelIndex sourceIndex = sourceModel()->index(row, 0, parent);
+    for (int r = start; r <= end; r++) {
+        const QModelIndex sourceIndex = sourceModel()->index(r, 0, parent);
         Q_ASSERT(sourceIndex.isValid());
         Node *parentNode = getParentNode(sourceIndex);
         if (!parentNode) {
@@ -454,7 +437,7 @@ void ReparentingModel::onSourceRowsInserted(const QModelIndex &parent, int start
             for (const QModelIndex &descendant : descendantsItem) {
                 if (Node *proxyNode = getReparentNode(descendant)) {
                     qCDebug(KORGANIZER_LOG) << "reparenting " << descendant.data().toString();
-                    int targetRow = proxyNode->children.size();
+                    const int targetRow = proxyNode->children.size();
                     beginInsertRows(index(proxyNode), targetRow, targetRow);
                     appendSourceNode(proxyNode, descendant);
                     reparented << descendant;
@@ -463,13 +446,14 @@ void ReparentingModel::onSourceRowsInserted(const QModelIndex &parent, int start
             }
         }
 
+        /* cppcheck-suppress knownConditionTrueFalse */
         if (parentNode->isSourceNode()) {
-            int targetRow = parentNode->children.size();
+            const int targetRow = parentNode->children.size();
             beginInsertRows(mapFromSource(parent), targetRow, targetRow);
             appendSourceNode(parentNode, sourceIndex, reparented);
             endInsertRows();
         } else { // Reparented
-            int targetRow = parentNode->children.size();
+            const int targetRow = parentNode->children.size();
             beginInsertRows(index(parentNode), targetRow, targetRow);
             appendSourceNode(parentNode, sourceIndex);
             endInsertRows();
@@ -481,8 +465,8 @@ void ReparentingModel::onSourceRowsAboutToBeRemoved(const QModelIndex &parent, i
 {
     // qCDebug(KORGANIZER_LOG) << objectName() << parent << start << end;
     // we remove in reverse order as otherwise the indexes in parentNode->children wouldn't be correct
-    for (int row = end; row >= start; row--) {
-        QModelIndex sourceIndex = sourceModel()->index(row, 0, parent);
+    for (int r = end; r >= start; r--) {
+        const QModelIndex sourceIndex = sourceModel()->index(r, 0, parent);
         Q_ASSERT(sourceIndex.isValid());
 
         const QModelIndex proxyIndex = mapFromSource(sourceIndex);
@@ -498,8 +482,8 @@ void ReparentingModel::onSourceRowsAboutToBeRemoved(const QModelIndex &parent, i
         }
     }
     // Allows the node manager to remove nodes that are no longer relevant
-    for (int row = start; row <= end; row++) {
-        mNodeManager->checkSourceIndexRemoval(sourceModel()->index(row, 0, parent));
+    for (int r = start; r <= end; r++) {
+        mNodeManager->checkSourceIndexRemoval(sourceModel()->index(r, 0, parent));
     }
 }
 
@@ -531,7 +515,7 @@ void ReparentingModel::onSourceRowsMoved(const QModelIndex & /* sourceParent */,
 
 void ReparentingModel::onSourceLayoutAboutToBeChanged()
 {
-    layoutAboutToBeChanged();
+    Q_EMIT layoutAboutToBeChanged();
     // Q_FOREACH(const QModelIndex &proxyPersistentIndex, persistentIndexList()) {
     //     Q_ASSERT(proxyPersistentIndex.isValid());
     //     const QPersistentModelIndex srcPersistentIndex = mapToSource(proxyPersistentIndex);
@@ -572,8 +556,8 @@ void ReparentingModel::onSourceLayoutChanged()
 void ReparentingModel::onSourceDataChanged(const QModelIndex &begin, const QModelIndex &end)
 {
     // qCDebug(KORGANIZER_LOG) << objectName() << begin << end;
-    for (int row = begin.row(); row <= end.row(); row++) {
-        mNodeManager->updateSourceIndex(sourceModel()->index(row, begin.column(), begin.parent()));
+    for (int r = begin.row(); r <= end.row(); r++) {
+        mNodeManager->updateSourceIndex(sourceModel()->index(r, begin.column(), begin.parent()));
     }
     Q_EMIT dataChanged(mapFromSource(begin), mapFromSource(end));
 }
@@ -619,12 +603,13 @@ QModelIndex ReparentingModel::index(int row, int column, const QModelIndex &pare
     return createIndex(row, column, node);
 }
 
-QModelIndex ReparentingModel::mapToSource(const QModelIndex &idx) const
+QModelIndex ReparentingModel::mapToSource(const QModelIndex &proxyIndex) const
 {
-    if (!idx.isValid() || !sourceModel()) {
+    if (!proxyIndex.isValid() || !sourceModel()) {
         return {};
     }
-    Node *node = extractNode(idx);
+    Node *node = extractNode(proxyIndex);
+    /* cppcheck-suppress knownConditionTrueFalse */
     if (!node->isSourceNode()) {
         return {};
     }
@@ -634,13 +619,10 @@ QModelIndex ReparentingModel::mapToSource(const QModelIndex &idx) const
 
 ReparentingModel::Node *ReparentingModel::getSourceNode(const QModelIndex &sourceIndex) const
 {
-    for (Node *n : std::as_const(mSourceNodes)) {
-        if (n->sourceIndex == sourceIndex) {
-            return n;
-        }
-    }
-    // qCDebug(KORGANIZER_LOG) << objectName() <<  "no node found for " << sourceIndex;
-    return nullptr;
+    const auto it = std::ranges::find_if(mSourceNodes, [sourceIndex](const Node *n) {
+        return n->sourceIndex == sourceIndex;
+    });
+    return it == mSourceNodes.end() ? nullptr : (*it);
 }
 
 QModelIndex ReparentingModel::mapFromSource(const QModelIndex &sourceIndex) const
@@ -676,13 +658,9 @@ void ReparentingModel::rebuildFromSource(Node *parentNode, const QModelIndex &so
 
 bool ReparentingModel::isDuplicate(const Node::Ptr &proxyNode) const
 {
-    for (const Node *n : std::as_const(mSourceNodes)) {
-        // qCDebug(KORGANIZER_LOG) << index << index.data().toString();
-        if (proxyNode->isDuplicateOf(n->sourceIndex)) {
-            return true;
-        }
-    }
-    return false;
+    return std::ranges::any_of(mSourceNodes, [proxyNode](const Node *n) {
+        return proxyNode->isDuplicateOf(n->sourceIndex);
+    });
 }
 
 void ReparentingModel::insertProxyNode(const Node::Ptr &proxyNode)
@@ -705,7 +683,7 @@ void ReparentingModel::reparentSourceNodes(const Node::Ptr &proxyNode)
             // cannot use them.
             const int oldRow = n->row();
             beginRemoveRows(index(n->parent), oldRow, oldRow);
-            Node::Ptr nodePtr = proxyNode->searchNode(n);
+            const Node::Ptr nodePtr = proxyNode->searchNode(n);
             // We lie about the row being removed already, but the view can deal with that better than if we call endRemoveRows after beginInsertRows
             endRemoveRows();
 
@@ -744,6 +722,7 @@ QVariant ReparentingModel::data(const QModelIndex &proxyIndex, int role) const
         return {};
     }
     const Node *node = extractNode(proxyIndex);
+    /* cppcheck-suppress knownConditionTrueFalse */
     if (node->isSourceNode()) {
         return sourceModel()->data(mapToSource(proxyIndex), role);
     }
@@ -760,6 +739,7 @@ bool ReparentingModel::setData(const QModelIndex &index, const QVariant &value,
         return false;
     }
     Node *node = extractNode(index);
+    /* cppcheck-suppress knownConditionTrueFalse */
     if (node->isSourceNode()) {
         return sourceModel()->setData(mapToSource(index), value, role);
     }
@@ -771,7 +751,8 @@ Qt::ItemFlags ReparentingModel::flags(const QModelIndex &index) const
     if (!index.isValid() || !sourceModel()) {
         return Qt::NoItemFlags;
     }
-    Node *node = extractNode(index);
+    const Node *node = extractNode(index);
+    /* cppcheck-suppress knownConditionTrueFalse */
     if (!node->isSourceNode()) {
         return Qt::ItemIsEnabled | Qt::ItemIsUserCheckable;
     }
@@ -819,7 +800,8 @@ QModelIndex ReparentingModel::buddy(const QModelIndex &index) const
     if (!index.isValid() || !sourceModel()) {
         return {};
     }
-    Node *node = extractNode(index);
+    const Node *node = extractNode(index);
+    /* cppcheck-suppress knownConditionTrueFalse */
     if (node->isSourceNode()) {
         return mapFromSource(sourceModel()->buddy(mapToSource(index)));
     }
